@@ -4,18 +4,20 @@
 
 ## Import des modules essentiels ##
 
-import giacpy as g
-from donnees import pi
+import giacpy
+import donnees
 import erreurs as er
 import random as r
 
 # Utilisation de Giac pour gestion des variables et des expressions et autres pitits trucs #
 
+## Definitions d'objets mathématiques généraux ##
+
 class Expression :
 
     def __init__(self,expr,var,cte = None) : #Création d'une expression à l'aide d'un str (Faire les filtres) !
         self.c = {"var" : var ,"cte" : cte}
-        self.Expr = g.giac(expr)
+        self.Expr = giacpy.giac(expr)
         self.sexpr = str(self.Expr)
         self.derivs = []
         self.ints = []
@@ -39,8 +41,8 @@ class Expression :
     def __add__(self,autre) :
         a = self.sexpr
         b = autre.sexpr
-        a = g.giac(a)
-        b = g.giac(b)
+        a = giacpy.giac(a)
+        b = giacpy.giac(b)
         c = a + b
         self.Expr = c
         self.sexpr = str(c)
@@ -53,20 +55,20 @@ class Expression :
     
     def eval(self,var,val) :
         a = self.subs(var,val)
-        b = g.giac(a)
+        b = giacpy.giac(a)
         return float(b)
     
     ## Calcul infinitesimal : derivees, integrales, limites ...##
 
     def deriv(self,var) : 
-        expr1 = g.diff(self.Expr,var)
+        expr1 = giacpy.diff(self.Expr,var)
         self.derivs.append(str(expr1))
         derivexpr = Expression(str(expr1),var=self.c)
         return derivexpr
     
     def int(self,var,a=None,b=None):
         if a == None and b == None :
-            self.Expr = g.int(self.Expr,var)
+            self.Expr = giacpy.int(self.Expr,var)
             self.ints.append(str(self.Expr))
             intexpr = Expression(str(self.Expr),var=self.c)
             return intexpr
@@ -74,7 +76,7 @@ class Expression :
             pass
 
     def simp(self) :
-        self.Expr = g.simplify(self.Expr)
+        self.Expr = giacpy.simplify(self.Expr)
         self.sexpr = str(self.Expr)
         return self
 
@@ -89,16 +91,14 @@ class Expression :
         self.derivs.append(jac)
         return jac
 
-    def hesse(self,ordre): #Renvoie la matrice hessienne d'une fonction ! (faire les filtres)
+    def hessi(self,ordre): #Renvoie la matrice hessienne d'une fonction ! (faire les filtres)
         pass
 
     def lim(self,var,val): #Renvoie la limite d'une fonction en une valeur (faire les filtres)
-        lim = g.limit(self.Expr,var,g.giac(val))
+        lim = giacpy.limit(self.Expr,var,giacpy.giac(val))
         lim = str(lim)
         return lim
 
-## Definitions d'objets mathématiques généraux ##
-
 class Matrice :
     """Classe permettant de creer et manipuler les matrices"""
     
@@ -203,9 +203,11 @@ class Matrice :
         else :
             er.Error_6()
 
-    def __rmul__(self,autre) : #Commutativite de la multiplication par un scalaire (faire les filtres)
+    def __rmul__(autre,self) : #Commutativite de la multiplication par un scalaire (faire les filtres)
         if isinstance(autre,int) :
             return self*autre
+        if isinstance(autre,Matrice):
+            return autre*self
 
     def __imul__(self,autre) : #Utilisation de l'operateur *= !
         return self * autre
@@ -213,8 +215,17 @@ class Matrice :
     def __div__(self,autre) : #Division nécessite la puissance (A faire) :
         pass
 
-    def __pow__(self) : #Mise à la puissance (A faire, necessite la def de l'inverse) !
-        pass
+    def __pow__(self,pui) : #Mise à la puissance (A finir, necessite la def de l'inverse) !
+        if pui == 0 :
+            if self.dim()[0] < self.dim()[1] :
+                n = self.dim()[0]
+            else :
+                n = self.dim()[1]
+            return matriceid(n)
+        if pui > 0 :
+            pass
+        if pui < 0:
+            pass
 
     def __eq__(self,autre) : #Verification de l'egalite (faire les filtres) !
         # + Verification matrice meme dimension
@@ -225,6 +236,9 @@ class Matrice :
                 else :
                     return True
     
+    def giac_convert(self) :
+        return giacpy.giac(self.Matrice)
+
     ## Methodes ##
 
     def dim(self): #Renvoie la dimension de la matrice !
@@ -258,11 +272,11 @@ class Matrice :
                 if i == j and self[i][j] == 0 :
                     for j in range(len(self[1])) :
                         if self[i][j] != 0 :
-                            self *= mel_permutation_l(i,j,self.dim()[1])
+                            self = self.permutation_lig(i,j,self.dim()[1])
                             p +=1
                 if i == j :
                     for k in range(1,self.dim()[0]-1) :
-                        self *= mel_transvection_l(i,k,(-self[k][i])/self[i][j],self.dim()[1])
+                        self = self.transvection_lig(i,k,(-self[k][i])/self[i][j],self.dim()[1])
         return (self,p)
 
     def det(self) : #Renvoie le determinant d'une matrice faire les filtres ! 
@@ -271,10 +285,9 @@ class Matrice :
                 det = self[0][0]*self[1][1] - self[0][1]*self[1][0]
                 return det
             else :
-                det = 1
-                for col in range(self.nbc) :
-                    pass
-
+                a = self.giac_convert()
+                det = giacpy.det(a)
+                return det
 
     def tranvesction_lig(self,ligne_1,ligne_2,valeur) : #Transvecte une ligne avec une autre d'une certaine valeur (faire les filtres) !
         n = self.dim()
@@ -286,23 +299,6 @@ class Matrice :
         a = mel_transvection(ligne_1,ligne_2,valeur,n[1])
         return self*a
 
-
-    def triangsup(self) : #finir et faire les autres matrices elementaires pour col et ligne/colo
-        nbl = self.nbl
-        nbc = self.nbc
-        cpt1 = 0
-        cpt2 = 0
-        for col in range(nbc) :
-            a = self[col][col]
-            for i in range(nbl) :
-                self[i][col] /= a
-            for lig in range(nbl) :
-                if col != lig :
-                    b = self
-                    self = self.tranvesction_lig(lig,cpt1,-self[cpt1][col])
-                    print(self)
-        return self
-
     def comatrice(self) : #Retourne la matrice de cofacteur d'une matrice (A faire) !
         pass
 
@@ -316,12 +312,33 @@ class Matrice :
         n = self.dim()
         pass
 
+    def eigenval(self) :
+        #Vérification matrice carrée
+        for i in range(self.dim()[0]) :
+            self[i][i] = Expression(str(self[i][i])+"-t",var=["t"])
+        det = self.det()
+        # Définir résolution polynomiale pour résolution det(A)=0
+
+    def eigenvec(self) :
+        pass
+
     def Spectre(self) : #Renvoie le spectre de la matrice si elle est diagonalisable (A faire) !
         pass
 
     def diago(self) :
         pass
 
+    def ker(self) :
+        pass
+
+    def tr(self) :
+        a = 0
+        for lig in range(self.nbl) :
+            for col in range(self.nbc) :
+                if col == lig :
+                    a += self[lig][col]
+        return a
+
 class Vecteur(Matrice) :
 
     def __init__(self,n) : #Initialisation d'un vecteur (genere le vecteur nul)
@@ -399,7 +416,7 @@ class Complexe :
             self.th = 0
         elif self.a == 0 and self.b != 0 :
             self.r = self.b
-            self.th = math.pi/2
+            self.th = donnees.pi/2
         return (self.r, self.th)
         pass
 
@@ -412,12 +429,7 @@ class Fonction(Expression) :
 
     ## Definition des fonction usuelles ##
     def sqrt(val = None) :
-        if val != None  :
-            cpt = 0
-            a = math.floor(val)
-            while cpt < 100 :
-                a = (a+(val)/a)/2
-            return a
+        pass
 
     def ln() :
         pass
@@ -437,8 +449,7 @@ class Fonction(Expression) :
     def etude() :
         pass
 
-    def param() :
-        pass
+    ## Définition des différents types de fonctions
 
 class Polynôme :
     def __init__(self):
@@ -537,24 +548,28 @@ def mel_dilatation(ligne,valeur,n) : #Matrice elementaire de dilatation d'une li
     return mat
 
 def mel_transvection(ligne_1,ligne_2,valeur,n) : #Matrice elementaire de transvections de 2 lignes (l1 prend la valeur de l1-valeur*l2) (faire les filtres) !
-    a = valeur*mat_creuse_1(ligne_1-1,ligne_2-1,1,n)
+    a = valeur * mat_creuse_1(ligne_2,ligne_1,1,n)
     mat = matriceid(n) +  a
     return mat
 
+
 ## Fonctions de Calcul algebrique ##
 
+
 def taylor(expr,var,pt,ordre) :
     expr.sucderiv(var,ordre)
 
+
 ## Fonctions Arithmétiques ##
 
-def PGCD(nb_1,nb_2) :
+
+def PGCD(nb_1,nb_2) : #Renvoie le plus grand diviseur commun de deux nombres
     pass
 
-def PPCM(nb_1,nb_2) :
+def PPCM(nb_1,nb_2) : #Renvoie le plus petit commun multiple de deux nombres
     pass
 
-def eratostene(n) :
+def eratostene(n) : #Renvoie une liste contenant tous les nombres premier de 1 jusqu'a n par le crible d'eratostene
     pass
 
 def segme(start,stop,step): #Faire les filtres
@@ -565,4 +580,23 @@ def segme(start,stop,step): #Faire les filtres
         if start > stop :
             break
         f.append(start)
-    return f
\ No newline at end of file
+    return f
+
+
+## Analyse numérique
+
+def regr() : #Regression linéaire, logarithmique, exponentielle ou puissance à partir de données
+    pass
+
+def MCNL () : #Curvefit avec la méthode des moindres carrées non linéaire
+    pass
+
+
+## Autres & vrac
+
+def red_gauss(q) :
+    return giacpy.gauss(q.Expr,q.c["var"])
+
+
+
+
