@@ -21,25 +21,21 @@ import maths as ma
 # c.show()
 
 # a = ma.randomatrice(3,3)
-# print(a)
+# print(a) 
 # b = a.pivots()
 # print (b)
 
-# h = ma.Expression("2*x**3-6*x*y+2*y**3-3*x-3*y",var=["x","y"])
-# print(h)
-# a = h.deriv("x").simp()
-# b = h.deriv("y").simp()
-# print(a)
-# print(b)
-# print(h)
+h = ma.Expression("2*x**3-6*x*y+2*y**3-3*x-3*y",var=["x","y"])
+print(h)
+a = h.deriv("x").simp()
+b = h.deriv("y").simp()
+print(a)
+print(b)
+print(h)
 
 # f = ma.Expression("e^(x^2-y)*(5-2*x+y)",var=["x","y"])
 # a = f.lim("x","+infinity")
 # print(a)
 
-a = ma.matrice123(5,5)
-print(a)
-# b = ma.(2,4,-2,5)
-# print(b*a)
-# a.triangsup()
-# print(a)
+a = ma.matrice123(4,4)
+print(a.eigenval())
\ No newline at end of file
